==> sumo_1.15.0+dfsg.orig.tar.xz: sumo-1_15_0/tests/netedit/demandelements/personflow/create/probability/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
# Copyright (C) 2009-2022 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2019-07-16

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot, ['--gui-testing-debug-gl'])

# go to demand mode
netedit.supermodeDemand()

# force save additionals
netedit.forceSaveAdditionals()

# go to person mode
netedit.personMode()

# change Person
netedit.changeElement("personFlow")

# change person plan
netedit.changePersonPlan("walk: edge->busStop", True)

# set invalid arrival pos
netedit.changeDefaultValue(netedit.attrs.personFlow.create.spacing, "dummySpacing")

# create route using edge and busStop
netedit.leftClick(referencePosition, 274, 400)
netedit.leftClick(referencePosition, 270, 43)

# press enter to create route
netedit.typeEnter()

# set invalid arrival pos
netedit.changeDefaultValue(netedit.attrs.personFlow.create.spacing, "personsPerHour")

# press enter to create flow
netedit.typeEnter()

# set valid arrival pos
netedit.changeDefaultValue(netedit.attrs.personFlow.create.spacingOption, "dummy")

# create flow
netedit.leftClick(referencePosition, 274, 392)
netedit.leftClick(referencePosition, 280, 55)

# press enter to create route
netedit.typeEnter()

# set valid arrival pos
netedit.changeDefaultValue(netedit.attrs.personFlow.create.spacingOption, "-30")

# press enter to create route
netedit.typeEnter()

# set valid arrival pos
netedit.changeDefaultValue(netedit.attrs.personFlow.create.spacingOption, "20.5")

# press enter to create route
netedit.typeEnter()

# set valid arrival pos
netedit.changeDefaultValue(netedit.attrs.personFlow.create.spacingOption, "22")

# create flow
netedit.leftClick(referencePosition, 274, 392)
netedit.leftClick(referencePosition, 280, 55)

# press enter to create route
netedit.typeEnter()

# Check undo redo
netedit.undo(referencePosition, 3)
netedit.redo(referencePosition, 3)

# save routes
netedit.saveRoutes(referencePosition)

# save additionals
netedit.saveAdditionals(referencePosition)

# save network
netedit.saveNetwork(referencePosition)

# quit netedit
netedit.quit(neteditProcess)

==> sumo_1.18.0+dfsg.orig.tar.xz: sumo-1_18_0/tests/netedit/demandelements/personflow/create/probability/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.dev/sumo
# Copyright (C) 2009-2023 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2019-07-16

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot)

# go to demand mode
netedit.supermodeDemand()

# go to person mode
netedit.personMode()

# change Person
netedit.changeElement("personFlow")

# change person plan
netedit.changePersonPlan("walk: busStop", True)

# set invalid arrival pos
netedit.changeDefaultValue(netedit.attrs.personFlow.create.spacing, "dummySpacing")

# create route using edge and busStop
netedit.leftClick(referencePosition, 274, 400)
netedit.leftClick(referencePosition, 270, 43)

# press enter to create route
netedit.typeEnter()

# set invalid arrival pos
netedit.changeDefaultValue(netedit.attrs.personFlow.create.spacing, "personsPerHour")

# press enter to create flow
netedit.typeEnter()

# set valid arrival pos
netedit.changeDefaultValue(netedit.attrs.personFlow.create.spacingOption, "dummy")

# create flow
netedit.leftClick(referencePosition, 274, 392)
netedit.leftClick(referencePosition, 280, 55)

# press enter to create route
netedit.typeEnter()

# set valid arrival pos
netedit.changeDefaultValue(netedit.attrs.personFlow.create.spacingOption, "-30")

# press enter to create route
netedit.typeEnter()

# set valid arrival pos
netedit.changeDefaultValue(netedit.attrs.personFlow.create.spacingOption, "20.5")

# press enter to create route
netedit.typeEnter()

# set valid arrival pos
netedit.changeDefaultValue(netedit.attrs.personFlow.create.spacingOption, "22")

# create flow
netedit.leftClick(referencePosition, 274, 392)
netedit.leftClick(referencePosition, 280, 55)

# press enter to create route
netedit.typeEnter()

# Check undo redo
netedit.undo(referencePosition, 3)
netedit.redo(referencePosition, 3)

# save Netedit config
netedit.saveNeteditConfig(referencePosition)

# quit netedit
netedit.quit(neteditProcess)
